package App::Unding;
$App::Unding::VERSION = '0.007';
use strict;
use warnings;
# Autor: Boris Däppen, 2018
# No guarantee given, use at own risk and will

# ABSTRACT: dark magic, encrypted wallet

use v5.6.0;

# THIS IS A STUB MODULE FOR CPAN INDEXING
# https://www.perl.com/article/how-to-upload-a-script-to-cpan/

__END__

=pod

=encoding UTF-8

=head1 NAME

App::Unding - dark magic, encrypted wallet

=head1 VERSION

version 0.007

=head1 SYNOPSIS

This is a stub module for cpan indexing.
No funcionality implemented.
See L<https://www.perl.com/article/how-to-upload-a-script-to-cpan/> for the reason.

You find the implementation in the script L<unding>.

=head1 AUTHOR

Boris Däppen <bdaeppen.perl@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Boris Däppen.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
